# User Guide

This user guide provides examples using _pywaterflood_ for a few tasks.

New users should start with {doc}`7-minutes-to-pywaterflood`.

```{toctree}
:maxdepth: 1
7-minutes-to-pywaterflood.ipynb
choosing-crm.ipynb
multiwell-productivity-index.ipynb
```
